% Cálculo das posições a solicitar a cada SCU para realizar um
% movimento de flexão das pernas.
%
% [pos_apply,k,t]=flexao(T,motion)
% T         -> Duração do movimento
% motion    -> Deslocamento a aplicar ao pé
% t         -> Array com os instantes temporais para cada movimento
% pos_apply -> Array de posições a aplicar a cada SCU
% k         -> Parametrização dos controladores PID

function [pos_apply,k,t]=inclinar(T,motion)

N_SCU=8;

% Inicialização da variável de retorno
pos_apply=zeros(N_SCU,3,1);
k=zeros(N_SCU,3,1,4);

% Duração do movimento
t=T;

% Posições a solicitar
pos_apply(1,:)=[+motion 0 0];
pos_apply(2,:)=[-motion 0 0];

for i=1:N_SCU
    % Adaptação para a posição a aplicar ao servo
    pos_apply(i,:)=adaptate(i,pos_apply(i,:));
    
    % Correcção da posição solicitada
    pos_apply(i,:)=correct(i,pos_apply(i,:));
    
    % Limitação
    pos_apply(i,:)=limit(i,pos_apply(i,:));
end
